use rodio::{Decoder, OutputStream, Sink};
use std::fs::File;
use std::io::BufReader;
use std::path::PathBuf;

#[derive(Debug, Clone)]
pub struct Alert {
    path: PathBuf,
}

impl Alert {
    pub fn new(path: PathBuf) -> Self {
        Self { path }
    }

    pub fn load(&mut self, path: PathBuf) {
        self.path = path;
    }

    pub fn play(&self) {
        let file = File::open(&self.path).unwrap();

        std::thread::spawn(move || {
            let (_stream, handle) = OutputStream::try_default().unwrap();
            let source = Decoder::new(BufReader::new(file)).unwrap();
            let sink = Sink::try_new(&handle).unwrap();

            sink.append(source);

            loop {
                if sink.len() == 0 {
                    break;
                }
            }

            println!("Exited Playback Thread.");
        });
    }
}
